==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/FleetVehicleInfo.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CONTRACTTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERID_Type;
import net.datastream.schemas.mp_fields.FLEETBILLINGID_Type;
import net.datastream.schemas.mp_fields.FLEETCUSTOMERID_Type;
import net.datastream.schemas.mp_fields.FLEETMARKUPID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.RENTALTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISVEHICLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETCUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETBILLINGID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETMARKUPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VEHICLESTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VEHICLETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RENTALTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AVAILABILITYSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "isvehicle",
    "fleetcustomerid",
    "fleetbillingid",
    "fleetmarkupid",
    "vehiclestatus",
    "vehicletype",
    "issueto",
    "isrental",
    "rentaltemplateid",
    "iscontract",
    "contracttemplateid",
    "customerid",
    "availabilitystatus"
})
@XmlRootElement(name = "FleetVehicleInfo")
public class FleetVehicleInfo {

    @XmlElement(name = "ISVEHICLE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isvehicle;
    @XmlElement(name = "FLEETCUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FLEETCUSTOMERID_Type fleetcustomerid;
    @XmlElement(name = "FLEETBILLINGID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FLEETBILLINGID_Type fleetbillingid;
    @XmlElement(name = "FLEETMARKUPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FLEETMARKUPID_Type fleetmarkupid;
    @XmlElement(name = "VEHICLESTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type vehiclestatus;
    @XmlElement(name = "VEHICLETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type vehicletype;
    @XmlElement(name = "ISSUETO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type issueto;
    @XmlElement(name = "ISRENTAL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "RENTALTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected RENTALTEMPLATEID_Type rentaltemplateid;
    @XmlElement(name = "ISCONTRACT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "CONTRACTTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "AVAILABILITYSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type availabilitystatus;

    /**
     * Obtient la valeur de la propriété isvehicle.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISVEHICLE() {
        return isvehicle;
    }

    /**
     * Définit la valeur de la propriété isvehicle.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISVEHICLE(String value) {
        this.isvehicle = value;
    }

    /**
     * Obtient la valeur de la propriété fleetcustomerid.
     * 
     * @return
     *     possible object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public FLEETCUSTOMERID_Type getFLEETCUSTOMERID() {
        return fleetcustomerid;
    }

    /**
     * Définit la valeur de la propriété fleetcustomerid.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public void setFLEETCUSTOMERID(FLEETCUSTOMERID_Type value) {
        this.fleetcustomerid = value;
    }

    /**
     * Obtient la valeur de la propriété fleetbillingid.
     * 
     * @return
     *     possible object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public FLEETBILLINGID_Type getFLEETBILLINGID() {
        return fleetbillingid;
    }

    /**
     * Définit la valeur de la propriété fleetbillingid.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public void setFLEETBILLINGID(FLEETBILLINGID_Type value) {
        this.fleetbillingid = value;
    }

    /**
     * Obtient la valeur de la propriété fleetmarkupid.
     * 
     * @return
     *     possible object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public FLEETMARKUPID_Type getFLEETMARKUPID() {
        return fleetmarkupid;
    }

    /**
     * Définit la valeur de la propriété fleetmarkupid.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public void setFLEETMARKUPID(FLEETMARKUPID_Type value) {
        this.fleetmarkupid = value;
    }

    /**
     * Obtient la valeur de la propriété vehiclestatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getVEHICLESTATUS() {
        return vehiclestatus;
    }

    /**
     * Définit la valeur de la propriété vehiclestatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setVEHICLESTATUS(STATUS_Type value) {
        this.vehiclestatus = value;
    }

    /**
     * Obtient la valeur de la propriété vehicletype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVEHICLETYPE() {
        return vehicletype;
    }

    /**
     * Définit la valeur de la propriété vehicletype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVEHICLETYPE(TYPE_Type value) {
        this.vehicletype = value;
    }

    /**
     * Obtient la valeur de la propriété issueto.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Définit la valeur de la propriété issueto.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

    /**
     * Obtient la valeur de la propriété isrental.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Définit la valeur de la propriété isrental.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Obtient la valeur de la propriété rentaltemplateid.
     * 
     * @return
     *     possible object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public RENTALTEMPLATEID_Type getRENTALTEMPLATEID() {
        return rentaltemplateid;
    }

    /**
     * Définit la valeur de la propriété rentaltemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public void setRENTALTEMPLATEID(RENTALTEMPLATEID_Type value) {
        this.rentaltemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété iscontract.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Définit la valeur de la propriété iscontract.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Obtient la valeur de la propriété contracttemplateid.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Définit la valeur de la propriété contracttemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété customerid.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Définit la valeur de la propriété customerid.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Obtient la valeur de la propriété availabilitystatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getAVAILABILITYSTATUS() {
        return availabilitystatus;
    }

    /**
     * Définit la valeur de la propriété availabilitystatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setAVAILABILITYSTATUS(STATUS_Type value) {
        this.availabilitystatus = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/FleetVehicleInfo.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CONTRACTTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERID_Type;
import net.datastream.schemas.mp_fields.FLEETBILLINGID_Type;
import net.datastream.schemas.mp_fields.FLEETCUSTOMERID_Type;
import net.datastream.schemas.mp_fields.FLEETMARKUPID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.RENTALTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISVEHICLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETCUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETBILLINGID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETMARKUPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VEHICLESTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VEHICLETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RENTALTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AVAILABILITYSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "isvehicle",
    "fleetcustomerid",
    "fleetbillingid",
    "fleetmarkupid",
    "vehiclestatus",
    "vehicletype",
    "issueto",
    "isrental",
    "rentaltemplateid",
    "iscontract",
    "contracttemplateid",
    "customerid",
    "availabilitystatus"
})
@XmlRootElement(name = "FleetVehicleInfo")
public class FleetVehicleInfo {

    @XmlElement(name = "ISVEHICLE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isvehicle;
    @XmlElement(name = "FLEETCUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FLEETCUSTOMERID_Type fleetcustomerid;
    @XmlElement(name = "FLEETBILLINGID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FLEETBILLINGID_Type fleetbillingid;
    @XmlElement(name = "FLEETMARKUPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected FLEETMARKUPID_Type fleetmarkupid;
    @XmlElement(name = "VEHICLESTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type vehiclestatus;
    @XmlElement(name = "VEHICLETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type vehicletype;
    @XmlElement(name = "ISSUETO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type issueto;
    @XmlElement(name = "ISRENTAL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "RENTALTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected RENTALTEMPLATEID_Type rentaltemplateid;
    @XmlElement(name = "ISCONTRACT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "CONTRACTTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "AVAILABILITYSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type availabilitystatus;

    /**
     * Gets the value of the isvehicle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISVEHICLE() {
        return isvehicle;
    }

    /**
     * Sets the value of the isvehicle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISVEHICLE(String value) {
        this.isvehicle = value;
    }

    /**
     * Gets the value of the fleetcustomerid property.
     * 
     * @return
     *     possible object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public FLEETCUSTOMERID_Type getFLEETCUSTOMERID() {
        return fleetcustomerid;
    }

    /**
     * Sets the value of the fleetcustomerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public void setFLEETCUSTOMERID(FLEETCUSTOMERID_Type value) {
        this.fleetcustomerid = value;
    }

    /**
     * Gets the value of the fleetbillingid property.
     * 
     * @return
     *     possible object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public FLEETBILLINGID_Type getFLEETBILLINGID() {
        return fleetbillingid;
    }

    /**
     * Sets the value of the fleetbillingid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public void setFLEETBILLINGID(FLEETBILLINGID_Type value) {
        this.fleetbillingid = value;
    }

    /**
     * Gets the value of the fleetmarkupid property.
     * 
     * @return
     *     possible object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public FLEETMARKUPID_Type getFLEETMARKUPID() {
        return fleetmarkupid;
    }

    /**
     * Sets the value of the fleetmarkupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETMARKUPID_Type }
     *     
     */
    public void setFLEETMARKUPID(FLEETMARKUPID_Type value) {
        this.fleetmarkupid = value;
    }

    /**
     * Gets the value of the vehiclestatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getVEHICLESTATUS() {
        return vehiclestatus;
    }

    /**
     * Sets the value of the vehiclestatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setVEHICLESTATUS(STATUS_Type value) {
        this.vehiclestatus = value;
    }

    /**
     * Gets the value of the vehicletype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVEHICLETYPE() {
        return vehicletype;
    }

    /**
     * Sets the value of the vehicletype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVEHICLETYPE(TYPE_Type value) {
        this.vehicletype = value;
    }

    /**
     * Gets the value of the issueto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getISSUETO() {
        return issueto;
    }

    /**
     * Sets the value of the issueto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setISSUETO(PERSONID_Type value) {
        this.issueto = value;
    }

    /**
     * Gets the value of the isrental property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Sets the value of the isrental property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Gets the value of the rentaltemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public RENTALTEMPLATEID_Type getRENTALTEMPLATEID() {
        return rentaltemplateid;
    }

    /**
     * Sets the value of the rentaltemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public void setRENTALTEMPLATEID(RENTALTEMPLATEID_Type value) {
        this.rentaltemplateid = value;
    }

    /**
     * Gets the value of the iscontract property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Sets the value of the iscontract property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the customerid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Sets the value of the customerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Gets the value of the availabilitystatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getAVAILABILITYSTATUS() {
        return availabilitystatus;
    }

    /**
     * Sets the value of the availabilitystatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setAVAILABILITYSTATUS(STATUS_Type value) {
        this.availabilitystatus = value;
    }

}
